# -*- coding: utf-8 -*-

__version__ = "1.1.5"

__name__ = 'useful_decoration'
__author__ = 'frank'
__email__ = '15769162764@163.com'

from useful_decoration.timer import fn_timer
from useful_decoration.timer import code_timer

from useful_decoration.decorations import element_mapping

from useful_decoration.single import single
from useful_decoration.single import singleton
